<?php
/**
 * Ventcamp functions related to style enqueue and displaying of the header.
 *
 * @since Ventcamp 1.0
 */

defined('ABSPATH') or die('No direct access');

if( !function_exists('ventcamp_lite_enqueue_styles') ) {
    /**
     * Enqueue Ventcamp styles
     */
    function ventcamp_lite_enqueue_styles() {
        // Register our styles
	    wp_enqueue_style( 'font-awesome',  BOWERPATH_URI . '/font-awesome/css/font-awesome.min.css' );
	    wp_enqueue_style( 'bootstrap',     BOWERPATH_URI . '/bootstrap/dist/css/bootstrap.min.css', array( 'font-awesome' ) );

        // Relative path to the theme style file
        $style_path = "/style.css";
        // Add last modification date as version to bypass caching
        $last_modification = date( "ymd-Gis", filemtime( THEME_DIR . $style_path ) );

        // Set bootstrap and other styles as dependencies
	    wp_enqueue_style( 'ventcamp-style',THEME_URI . $style_path, array ( 'bootstrap', 'font-awesome' ), $last_modification );
    }

    add_action('wp_enqueue_scripts', 'ventcamp_lite_enqueue_styles', 50);
}

if ( !function_exists('ventcamp_lite_link_to_menu_editor') ) {
    /**
     * Menu fallback. Link to the menu editor if that is useful.
     *
     * @param array $args Array of arguments
     * @see wp-includes/nav-menu-template.php for available arguments
     *
     * @return string|bool Link to the editor
     */
    function ventcamp_lite_link_to_menu_editor ( $args ) {
        // Only privileged users can see 'add a menu' link
        if ( !current_user_can( 'manage_options' ) ) {
            return false;
        }

        // Extract all arguments into variables
        extract( $args );

        // Link to menu editor
        $link = $link_before . '<a href="' . admin_url( 'nav-menus.php' ) . '">' . $before . __( 'Add a menu', 'ventcamp-lite' ) . $after . '</a>' . $link_after;
        // Wrap link in <li> tag
        $link = "<li>$link</li>";

        // Make a formatted string, wrapper in specified tag with menu id and menu class
        $output = sprintf( $items_wrap, $menu_id, $menu_class, $link );

        // Only if container is not empty
        if ( !empty( $container ) ) {
            $output  = "<$container class='$container_class' id='$container_id'>$output</$container>";
        }

        // If echo flag is set
        if ( $args['echo'] ) {
            echo $output;
        }

        return $output;
    }
}

if ( !function_exists('ventcamp_lite_header_menu') ) {
    /**
     * Show menu in header, if menu is enabled in settings
     */
    function ventcamp_lite_header_menu () {
        // Default value for header_format_style
        $default = 'logo_menu_button';
        $header_format = explode("_", ventcamp_lite_option( 'header_format_style', $default ));

        if( in_array('menu', $header_format) ) {
            wp_nav_menu( array(
                'theme_location' => 'primary',
                'container' => false,
                'menu_class' => 'navigation-list pull-left',
                'echo' => true,
                'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s</ul>',
                'depth' => 2,
                'fallback_cb' => 'ventcamp_lite_link_to_menu_editor',
            ));
        }
    }
}

if ( !function_exists('ventcamp_lite_header_logo') ) {
    /**
     * Output the custom logo. If there is no selected logo, then display the site's name.
     */
    function ventcamp_lite_header_logo () {
	    // Try to retrieve the Custom Logo
	    $output = '';
	    if ( function_exists( 'get_custom_logo' ) ) {
		    $output = get_custom_logo();
        }

	    // Nothing in the output: Custom Logo is not supported, or there is no selected logo
	    // In both cases we display the site's name
	    if ( empty( $output ) ) {
		    $output = '<h1><a href="' . esc_url(home_url('/')) . '">' . get_bloginfo('name') . '</a></h1>';
        }

	    echo $output;
    }
}
