<?php
/**
 *
 * Ventcamp WP Theme functions
 *
 * @author Vivaco
 * @license Free License
 * @link http://vivaco.com
 * @copyright 2017 Vivaco
 * @package Ventcamp
 * @version 1.0.0
 *
 */
defined('ABSPATH') or die('No direct access');

// Name of the theme
define( 'THEME_NAME', 'ventcamp-lite' );

// Path constants
define( 'THEME_DIR', get_template_directory() );
define( 'THEME_URI', get_template_directory_uri() );

define( 'ASSETS_URI',       THEME_URI . '/assets/' );
define( 'BOWERPATH_URI',    ASSETS_URI . '/bower/' );
define( 'IMAGESPATH_URI',   ASSETS_URI . '/images/' );
define( 'SCRIPTSPATH_URI',  ASSETS_URI . '/javascripts/' );
define( 'STYLESPATH_URI',   ASSETS_URI . '/stylesheets/' );

// Theme main variables
define('ventcamp_lite_BLOG_IMAGE_LARGE_W', 860);
define('ventcamp_lite_BLOG_IMAGE_LARGE_H', 340);

define('ventcamp_lite_FOOTER_RECENTCOMMENTS_LENGTH', 25); // Recent comments title length in footer
define('ventcamp_lite_FOOTER_RECENTPOSTS_LENGTH', 25);	// Recent posts title length in footer

if( !function_exists('ventcamp_lite_theme_setup') ) {
	function ventcamp_lite_theme_setup() {
		load_theme_textdomain( 'ventcamp-lite', get_template_directory() . '/languages' );
		add_theme_support( 'title-tag' );
		add_theme_support( 'caption' );

		if ( ! isset( $content_width ) ) $content_width = 960;

		add_editor_style();

		// This feature allows Ventcamp to add custom logo.
		add_theme_support( 'custom-logo', array(
			'height'      => 85,
			'width'       => 160,
			'flex-height' => true,
			'flex-width'  => true,
			'header-text' => array( 'site-title', 'site-description' ),
		) );
		
		add_theme_support( 'custom-header' );
		add_theme_support( 'custom-background' );
		
		add_theme_support( 'post-thumbnails' );
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'title-tag' );

		add_theme_support( 'custom_css' );

		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		add_theme_support( 'post-formats', array(
			'aside',
			'image',
			'video',
			'quote',
			'link',
		) );

		add_image_size( '70x70', 70, 70, false );

		register_nav_menus( array(
			'primary' => esc_html__( 'Primary Menu', 'ventcamp-lite' ),
			'footer'  => esc_html__( 'Footer Menu', 'ventcamp-lite' ),
		) );
	}
}

add_action( 'after_setup_theme', 'ventcamp_lite_theme_setup' );

if( !function_exists('ventcamp_lite_option' ) ) {
    /**
     * Helper function to return option value.
     * If the value is not set, returns $default
     *
     * @param string $name Name of the option
     * @param mixed $default Default value for option
     *
     * @return bool Result
     */
    function ventcamp_lite_option( $name = '', $default = false ){
        if ( class_exists( 'Kirki' ) ) {
            $value = Kirki::get_option( 'ventcamp_lite_theme_config', $name );

            if ( isset( $value ) ) {
                return $value;
            }
        }

        return $default;
    }
}

/**
 * Displays all messages registered to 'options-framework'
 */
function ventcamp_lite_admin_notices_action() {
    settings_errors( 'ventcamp-notices' );
}
add_action( 'admin_notices', 'ventcamp_lite_admin_notices_action' );

// Include Theme libraries and dependencies
if ( function_exists( 'is_plugin_active' ) ){
    // Only if WooCommerce plugin is active, require custom woocommerce functionality
    if ( is_plugin_active( 'woocommerce/woocommerce.php' ) ) {
        require_once THEME_DIR . '/extensions/woocommerce.class.php';
    }
}

// Add theme settings
require_once THEME_DIR . '/extensions/theme-settings.class.php';

// Add ventcamp widgets
require_once ( THEME_DIR . '/includes/ventcamp_lite_widgets.php' );

// Add misc template overrides
require_once ( THEME_DIR . '/includes/ventcamp_lite_template_tags.php' );

// Add aqua thumbnail resizer
require_once ( THEME_DIR . '/includes/lib/aqua-resizer/aqua-resizer.php' );

// Adding theme specific widget overrides
require_once ( THEME_DIR . '/includes/widgets/ventcamp_lite_widget_Recent_Posts.php' );
require_once ( THEME_DIR . '/includes/widgets/ventcamp_lite_widget_Recent_Comments.php' );
require_once ( THEME_DIR . '/includes/widgets/ventcamp_lite_widget_About.php' );

// Load custom footer helpers
require_once ( THEME_DIR . '/extensions/footer-extensions.php');

// Load custom header helpers
require_once ( THEME_DIR . '/extensions/header-extensions.php' );

// Load comment section helpers
require_once ( THEME_DIR . '/extensions/discussion-extensions.php');

add_filter( 'lostpassword_url', 'remove_all_lostpassword_filters', PHP_INT_MAX, 2 );
/**
 * Bugfix: remove woocommerce filter for 'lostpassword_url', because it gives 404 error
 */
if ( !function_exists( 'remove_all_lostpassword_filters' ) ){
	function remove_all_lostpassword_filters( $url, $redirect ) {
	    remove_all_filters( 'lostpassword_url' );

	    return wp_lostpassword_url( $redirect );
	}
}

// Load custom content helpers
require_once ( THEME_DIR . '/extensions/content-extensions.php' );
